@@ -8,6 +8,7 @@ from enum import Enum
 
 
 class WSState(Enum):
+    """This enum is used to represent the websocket state"""
     init = "init"
     connecting = "connecting"
     open = "open"
@@ -16,14 +17,13 @@ class WSState(Enum):
 
 
 class ConnectionType(Enum):
+    """This enum is used to represent the connection type"""
     http: str = "http"
     ws: str = "websocket"
 
 
 class Request:
-    asgi3 = "ASGI3"
-    asgi2 = "ASGI2"
-
+    """This class represents a request from the client to the server"""
     def __init__(
         self,
         scope: dict,
@@ -41,36 +41,45 @@ class Request:
 
     @property
     def path(self) -> str:
+        """Displays the path that the client uses"""
         return self._scope["path"]
 
     @property
     def method(self) -> str:
+        """Represents the method that the client uses when making the request."""
         return self._scope["method"].lower()
 
     @property
     def client(self) -> str:
+        """Specifies the address and port through which the client connects to the server. ex. (addr,port)"""
         return self._scope["client"]
 
     @property
     def server(self) -> str:
+        """Retrieves the address of the server to which the CLient connects."""
         return self._scope["server"]
 
     @property
     def headers(self) -> CIMultiDict:
+        """Retrieves all headers sent by the client during the request"""
         if not self._req_headers:
             self._req_headers = CIMultiDict(
                 [(k.decode("ascii"), v.decode("ascii")) for (k, v) in self._scope["headers"]])
         return self._req_headers
 
     @property
-    def cookies(self) -> SimpleCookie:
+    def cookies_raw(self) -> SimpleCookie:
+        """Retrieves all cookies sent by the client during the request"""
         if not self._req_headers:
+            self._req_headers = CIMultiDict(
+                [(k.decode("ascii"), v.decode("ascii")) for (k, v) in self._scope["headers"]])
             self._req_cookies.load(self._req_headers.get("cookie", {}))
         return self._req_cookies
 
     @property
-    def cookies_dict(self) -> dict:
-        return {key: m.value for key, m in self._req_cookies.items()}
+    def cookies(self) -> dict:
+        """Retrieves all cookies sent by the client during the request as dict"""
+        return {key: m.value for key, m in self.cookies_raw.items()}
 
     @property
     def scope(self) -> dict:
@@ -78,10 +87,12 @@ class Request:
 
     @property
     def query(self) -> dict:
+        """Retrieves the querystring as dict"""
         return CIMultiDict(parse_qsl(self.scope.get("query_string", b"").decode("utf-8")))
 
     @property
     def type(self) -> ConnectionType:
+        """retrieves the connection type of the request"""
         return ConnectionType.ws if self.scope.get("type") == "websocket" else ConnectionType.http
 
     async def body_iter(self):
@@ -113,6 +124,7 @@ class Request:
             yield bytes(chunk)
 
     async def body(self) -> bytes:
+        """Retrieves the request body"""
         data: bytes = b"".join([chunks async for chunks in self.body_iter()])
         try:
             return json.loads(data)
