@@ -14,6 +14,6 @@ class StaticFiles:
     def provide(self, filepath: str):
         mime = MimeTypes()
         typ = mime.guess_type("." + filepath)
-        with open("."+filepath, "rb") as f:
+        with open("." + filepath, "rb") as f:
             content = f.read()
-        return (content, typ[0])
\ No newline at end of file
+        return content, typ[0]
